summaryrefslogtreecommitdiffstats
path: root/vendor/github.com/mattermost/mattermost-server
diff options
context:
space:
mode:
authorWim <wim@42.be>2022-03-12 19:41:07 +0100
committerGitHub <noreply@github.com>2022-03-12 19:41:07 +0100
commitb3be2e208cb373207d6199cac5a9fc92be073e7a (patch)
tree6de6d444737edee8f0476eea87c233fa980f0002 /vendor/github.com/mattermost/mattermost-server
parentc30e90ff3f7e9ff96ac79ed4b7d90d6346216a15 (diff)
downloadmatterbridge-msglm-b3be2e208cb373207d6199cac5a9fc92be073e7a.tar.gz
matterbridge-msglm-b3be2e208cb373207d6199cac5a9fc92be073e7a.tar.bz2
matterbridge-msglm-b3be2e208cb373207d6199cac5a9fc92be073e7a.zip
Update dependencies and vendor (#1761)
Diffstat (limited to 'vendor/github.com/mattermost/mattermost-server')
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/NOTICE.txt2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/channel.go6
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/channel_count.go2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/client4.go5
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/cloud.go26
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/config.go46
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/data_retention_policy.go2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/feature_flags.go15
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/post.go6
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/post_list.go6
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/post_metadata.go2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/post_search_results.go6
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/role.go2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/session.go1
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/team_member.go1
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/user.go6
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/user_serial_gen.go34
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/utils.go27
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/model/version.go3
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/shared/filestore/s3_overrides.go2
-rw-r--r--vendor/github.com/mattermost/mattermost-server/v6/shared/mlog/mlog.go4
21 files changed, 149 insertions, 55 deletions
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/NOTICE.txt b/vendor/github.com/mattermost/mattermost-server/v6/NOTICE.txt
index 0d3d8dd9..3f186ef7 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/NOTICE.txt
+++ b/vendor/github.com/mattermost/mattermost-server/v6/NOTICE.txt
@@ -4494,7 +4494,7 @@ SOFTWARE.
This product contains 'archiver' by Matthew Holt
-A library to handle direferen archive files (zip, rar, tar.gz...)
+A library to handle different archive files (zip, rar, tar.gz...)
* HOMEPAGE:
* https://github.com/mholt/archiver
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/channel.go b/vendor/github.com/mattermost/mattermost-server/v6/model/channel.go
index 20604700..dfa40347 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/channel.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/channel.go
@@ -144,9 +144,9 @@ type ChannelSearchOpts struct {
}
type ChannelMemberCountByGroup struct {
- GroupId string `db:"-" json:"group_id"`
- ChannelMemberCount int64 `db:"-" json:"channel_member_count"`
- ChannelMemberTimezonesCount int64 `db:"-" json:"channel_member_timezones_count"`
+ GroupId string `json:"group_id"`
+ ChannelMemberCount int64 `json:"channel_member_count"`
+ ChannelMemberTimezonesCount int64 `json:"channel_member_timezones_count"`
}
type ChannelOption func(channel *Channel)
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/channel_count.go b/vendor/github.com/mattermost/mattermost-server/v6/model/channel_count.go
index 25329a15..17cea756 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/channel_count.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/channel_count.go
@@ -17,7 +17,7 @@ type ChannelCounts struct {
}
func (o *ChannelCounts) Etag() string {
- // we don't include CountsRoot in ETag calculation, since it's a deriviative
+ // we don't include CountsRoot in ETag calculation, since it's a derivative
ids := []string{}
for id := range o.Counts {
ids = append(ids, id)
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/client4.go b/vendor/github.com/mattermost/mattermost-server/v6/model/client4.go
index dd9de4d0..d4213d15 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/client4.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/client4.go
@@ -1978,7 +1978,7 @@ func (c *Client4) GetBotsIncludeDeleted(page, perPage int, etag string) ([]*Bot,
return bots, BuildResponse(r), nil
}
-// GetBotsOrphaned fetches the given page of bots, only including orphanded bots.
+// GetBotsOrphaned fetches the given page of bots, only including orphaned bots.
func (c *Client4) GetBotsOrphaned(page, perPage int, etag string) ([]*Bot, *Response, error) {
query := fmt.Sprintf("?page=%v&per_page=%v&only_orphaned="+c.boolString(true), page, perPage)
r, err := c.DoAPIGet(c.botsRoute()+query, etag)
@@ -4438,6 +4438,9 @@ func (c *Client4) UpdateConfig(config *Config) (*Config, *Response, error) {
}
// MigrateConfig will migrate existing config to the new one.
+// DEPRECATED: The config migrate API has been moved to be a purely
+// mmctl --local endpoint. This method will be removed in a
+// future major release.
func (c *Client4) MigrateConfig(from, to string) (*Response, error) {
m := make(map[string]string, 2)
m["from"] = from
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/cloud.go b/vendor/github.com/mattermost/mattermost-server/v6/model/cloud.go
index 7c63c138..90fc7f94 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/cloud.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/cloud.go
@@ -70,6 +70,7 @@ type StripeSetupIntent struct {
// ConfirmPaymentMethodRequest contains the fields for the customer payment update API.
type ConfirmPaymentMethodRequest struct {
StripeSetupIntentID string `json:"stripe_setup_intent_id"`
+ SubscriptionID string `json:"subscription_id"`
}
// Customer model represents a customer on the system.
@@ -137,24 +138,25 @@ func (s *Subscription) GetWorkSpaceNameFromDNS() string {
// Invoice model represents a cloud invoice
type Invoice struct {
- ID string `json:"id"`
- Number string `json:"number"`
- CreateAt int64 `json:"create_at"`
- Total int64 `json:"total"`
- Tax int64 `json:"tax"`
- Status string `json:"status"`
- Description string `json:"description"`
- PeriodStart int64 `json:"period_start"`
- PeriodEnd int64 `json:"period_end"`
- SubscriptionID string `json:"subscription_id"`
- Items []*InvoiceLineItem `json:"line_items"`
+ ID string `json:"id"`
+ Number string `json:"number"`
+ CreateAt int64 `json:"create_at"`
+ Total int64 `json:"total"`
+ Tax int64 `json:"tax"`
+ Status string `json:"status"`
+ Description string `json:"description"`
+ PeriodStart int64 `json:"period_start"`
+ PeriodEnd int64 `json:"period_end"`
+ SubscriptionID string `json:"subscription_id"`
+ Items []*InvoiceLineItem `json:"line_items"`
+ CurrentProductName string `json:"current_product_name"`
}
// InvoiceLineItem model represents a cloud invoice lineitem tied to an invoice.
type InvoiceLineItem struct {
PriceID string `json:"price_id"`
Total int64 `json:"total"`
- Quantity int64 `json:"quantity"`
+ Quantity float64 `json:"quantity"`
PricePerUnit int64 `json:"price_per_unit"`
Description string `json:"description"`
Type string `json:"type"`
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/config.go b/vendor/github.com/mattermost/mattermost-server/v6/model/config.go
index bec5afbe..d70b06b5 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/config.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/config.go
@@ -126,7 +126,7 @@ const (
EmailSettingsDefaultFeedbackOrganization = ""
- SupportSettingsDefaultTermsOfServiceLink = "https://mattermost.com/terms-of-service/"
+ SupportSettingsDefaultTermsOfServiceLink = "https://mattermost.com/terms-of-use/"
SupportSettingsDefaultPrivacyPolicyLink = "https://mattermost.com/privacy-policy/"
SupportSettingsDefaultAboutLink = "https://about.mattermost.com/default-about/"
SupportSettingsDefaultHelpLink = "https://about.mattermost.com/default-help/"
@@ -202,6 +202,7 @@ const (
DataRetentionSettingsDefaultMessageRetentionDays = 365
DataRetentionSettingsDefaultFileRetentionDays = 365
+ DataRetentionSettingsDefaultBoardsRetentionDays = 365
DataRetentionSettingsDefaultDeletionJobStartTime = "02:00"
DataRetentionSettingsDefaultBatchSize = 3000
@@ -771,7 +772,7 @@ func (s *ServiceSettings) SetDefaults(isUpdate bool) {
}
if s.ThreadAutoFollow == nil {
- s.ThreadAutoFollow = NewBool(true)
+ s.ThreadAutoFollow = NewBool(false)
}
if s.CollapsedThreads == nil {
@@ -1074,19 +1075,20 @@ type ReplicaLagSettings struct {
}
type SqlSettings struct {
- DriverName *string `access:"environment_database,write_restrictable,cloud_restrictable"`
- DataSource *string `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
- DataSourceReplicas []string `access:"environment_database,write_restrictable,cloud_restrictable"`
- DataSourceSearchReplicas []string `access:"environment_database,write_restrictable,cloud_restrictable"`
- MaxIdleConns *int `access:"environment_database,write_restrictable,cloud_restrictable"`
- ConnMaxLifetimeMilliseconds *int `access:"environment_database,write_restrictable,cloud_restrictable"`
- ConnMaxIdleTimeMilliseconds *int `access:"environment_database,write_restrictable,cloud_restrictable"`
- MaxOpenConns *int `access:"environment_database,write_restrictable,cloud_restrictable"`
- Trace *bool `access:"environment_database,write_restrictable,cloud_restrictable"`
- AtRestEncryptKey *string `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
- QueryTimeout *int `access:"environment_database,write_restrictable,cloud_restrictable"`
- DisableDatabaseSearch *bool `access:"environment_database,write_restrictable,cloud_restrictable"`
- ReplicaLagSettings []*ReplicaLagSettings `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
+ DriverName *string `access:"environment_database,write_restrictable,cloud_restrictable"`
+ DataSource *string `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
+ DataSourceReplicas []string `access:"environment_database,write_restrictable,cloud_restrictable"`
+ DataSourceSearchReplicas []string `access:"environment_database,write_restrictable,cloud_restrictable"`
+ MaxIdleConns *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ ConnMaxLifetimeMilliseconds *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ ConnMaxIdleTimeMilliseconds *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ MaxOpenConns *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ Trace *bool `access:"environment_database,write_restrictable,cloud_restrictable"`
+ AtRestEncryptKey *string `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
+ QueryTimeout *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ DisableDatabaseSearch *bool `access:"environment_database,write_restrictable,cloud_restrictable"`
+ MigrationsStatementTimeoutSeconds *int `access:"environment_database,write_restrictable,cloud_restrictable"`
+ ReplicaLagSettings []*ReplicaLagSettings `access:"environment_database,write_restrictable,cloud_restrictable"` // telemetry: none
}
func (s *SqlSettings) SetDefaults(isUpdate bool) {
@@ -1144,6 +1146,10 @@ func (s *SqlSettings) SetDefaults(isUpdate bool) {
s.DisableDatabaseSearch = NewBool(false)
}
+ if s.MigrationsStatementTimeoutSeconds == nil {
+ s.MigrationsStatementTimeoutSeconds = NewInt(100000)
+ }
+
if s.ReplicaLagSettings == nil {
s.ReplicaLagSettings = []*ReplicaLagSettings{}
}
@@ -2581,8 +2587,10 @@ func (bs *BleveSettings) SetDefaults() {
type DataRetentionSettings struct {
EnableMessageDeletion *bool `access:"compliance_data_retention_policy"`
EnableFileDeletion *bool `access:"compliance_data_retention_policy"`
+ EnableBoardsDeletion *bool `access:"compliance_data_retention_policy"`
MessageRetentionDays *int `access:"compliance_data_retention_policy"`
FileRetentionDays *int `access:"compliance_data_retention_policy"`
+ BoardsRetentionDays *int `access:"compliance_data_retention_policy"`
DeletionJobStartTime *string `access:"compliance_data_retention_policy"`
BatchSize *int `access:"compliance_data_retention_policy"`
}
@@ -2596,6 +2604,10 @@ func (s *DataRetentionSettings) SetDefaults() {
s.EnableFileDeletion = NewBool(false)
}
+ if s.EnableBoardsDeletion == nil {
+ s.EnableBoardsDeletion = NewBool(false)
+ }
+
if s.MessageRetentionDays == nil {
s.MessageRetentionDays = NewInt(DataRetentionSettingsDefaultMessageRetentionDays)
}
@@ -2604,6 +2616,10 @@ func (s *DataRetentionSettings) SetDefaults() {
s.FileRetentionDays = NewInt(DataRetentionSettingsDefaultFileRetentionDays)
}
+ if s.BoardsRetentionDays == nil {
+ s.BoardsRetentionDays = NewInt(DataRetentionSettingsDefaultBoardsRetentionDays)
+ }
+
if s.DeletionJobStartTime == nil {
s.DeletionJobStartTime = NewString(DataRetentionSettingsDefaultDeletionJobStartTime)
}
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/data_retention_policy.go b/vendor/github.com/mattermost/mattermost-server/v6/model/data_retention_policy.go
index 0a1d318e..32102517 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/data_retention_policy.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/data_retention_policy.go
@@ -6,8 +6,10 @@ package model
type GlobalRetentionPolicy struct {
MessageDeletionEnabled bool `json:"message_deletion_enabled"`
FileDeletionEnabled bool `json:"file_deletion_enabled"`
+ BoardsDeletionEnabled bool `json:"boards_deletion_enabled"`
MessageRetentionCutoff int64 `json:"message_retention_cutoff"`
FileRetentionCutoff int64 `json:"file_retention_cutoff"`
+ BoardsRetentionCutoff int64 `json:"boards_retention_cutoff"`
}
type RetentionPolicy struct {
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/feature_flags.go b/vendor/github.com/mattermost/mattermost-server/v6/model/feature_flags.go
index a2d53e34..6998a03a 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/feature_flags.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/feature_flags.go
@@ -47,9 +47,6 @@ type FeatureFlags struct {
// Determine whether when a user gets created, they'll have noisy notifications e.g. Send desktop notifications for all activity
NewAccountNoisy bool
- // Enable Boards Unfurl Preview
- BoardsUnfurl bool
-
// Enable Calls plugin support in the mobile app
CallsMobile bool
@@ -70,6 +67,14 @@ type FeatureFlags struct {
// A/B test for whether radio buttons or toggle button is more effective in in-screen invite to team modal ("none", "toggle")
InviteToTeam string
+
+ // Enable inline post editing
+ InlinePostEditing bool
+
+ // Enable DataRetention for Boards
+ BoardsDataRetention bool
+
+ NormalizeLdapDNs bool
}
func (f *FeatureFlags) SetDefaults() {
@@ -86,7 +91,6 @@ func (f *FeatureFlags) SetDefaults() {
f.GlobalHeader = true
f.AddChannelButton = "by_team_name"
f.NewAccountNoisy = false
- f.BoardsUnfurl = true
f.CallsMobile = false
f.AutoTour = "none"
f.BoardsFeatureFlags = ""
@@ -94,6 +98,9 @@ func (f *FeatureFlags) SetDefaults() {
f.GuidedChannelCreation = false
f.ResendInviteEmailInterval = ""
f.InviteToTeam = "none"
+ f.InlinePostEditing = false
+ f.BoardsDataRetention = false
+ f.NormalizeLdapDNs = false
}
func (f *FeatureFlags) Plugins() map[string]string {
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/post.go b/vendor/github.com/mattermost/mattermost-server/v6/model/post.go
index d13fef0a..87c1f338 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/post.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/post.go
@@ -6,6 +6,7 @@ package model
import (
"encoding/json"
"errors"
+ "io"
"net/http"
"regexp"
"sort"
@@ -227,6 +228,11 @@ func (o *Post) ToJSON() (string, error) {
return string(b), err
}
+func (o *Post) EncodeJSON(w io.Writer) error {
+ o.StripActionIntegrations()
+ return json.NewEncoder(w).Encode(o)
+}
+
type GetPostsSinceOptions struct {
UserId string
ChannelId string
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/post_list.go b/vendor/github.com/mattermost/mattermost-server/v6/model/post_list.go
index 933d1f8f..bb28063a 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/post_list.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/post_list.go
@@ -5,6 +5,7 @@ package model
import (
"encoding/json"
+ "io"
"sort"
)
@@ -80,6 +81,11 @@ func (o *PostList) ToJSON() (string, error) {
return string(b), err
}
+func (o *PostList) EncodeJSON(w io.Writer) error {
+ o.StripActionIntegrations()
+ return json.NewEncoder(w).Encode(o)
+}
+
func (o *PostList) MakeNonNil() {
if o.Order == nil {
o.Order = make([]string, 0)
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/post_metadata.go b/vendor/github.com/mattermost/mattermost-server/v6/model/post_metadata.go
index 0f9e61d3..6ccc1ebf 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/post_metadata.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/post_metadata.go
@@ -14,7 +14,7 @@ type PostMetadata struct {
// Files holds information about the file attachments on the post.
Files []*FileInfo `json:"files,omitempty"`
- // Images holds the dimensions of all external images in the post as a map of the image URL to its diemsnions.
+ // Images holds the dimensions of all external images in the post as a map of the image URL to its dimensions.
// This includes image embeds (when the message contains a plaintext link to an image), Markdown images, images
// contained in the OpenGraph metadata, and images contained in message attachments. It does not contain
// the dimensions of any file attachments as those are stored in FileInfos.
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/post_search_results.go b/vendor/github.com/mattermost/mattermost-server/v6/model/post_search_results.go
index 92e044a7..a3afc723 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/post_search_results.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/post_search_results.go
@@ -5,6 +5,7 @@ package model
import (
"encoding/json"
+ "io"
)
type PostSearchMatches map[string][]string
@@ -27,3 +28,8 @@ func (o *PostSearchResults) ToJSON() (string, error) {
b, err := json.Marshal(&copy)
return string(b), err
}
+
+func (o *PostSearchResults) EncodeJSON(w io.Writer) error {
+ o.PostList.StripActionIntegrations()
+ return json.NewEncoder(w).Encode(o)
+}
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/role.go b/vendor/github.com/mattermost/mattermost-server/v6/model/role.go
index b8d75d4b..0dcb405c 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/role.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/role.go
@@ -558,7 +558,7 @@ func (r *Role) GetChannelModeratedPermissions(channelType ChannelType) map[strin
return moderatedPermissions
}
-// RolePatchFromChannelModerationsPatch Creates and returns a RolePatch based on a slice of ChannelModerationPatchs, roleName is expected to be either "members" or "guests".
+// RolePatchFromChannelModerationsPatch Creates and returns a RolePatch based on a slice of ChannelModerationPatches, roleName is expected to be either "members" or "guests".
func (r *Role) RolePatchFromChannelModerationsPatch(channelModerationsPatch []*ChannelModerationPatch, roleName string) *RolePatch {
permissionsToAddToPatch := make(map[string]bool)
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/session.go b/vendor/github.com/mattermost/mattermost-server/v6/model/session.go
index 72f8d646..36955583 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/session.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/session.go
@@ -15,6 +15,7 @@ const (
SessionCookieToken = "MMAUTHTOKEN"
SessionCookieUser = "MMUSERID"
SessionCookieCsrf = "MMCSRF"
+ SessionCookieCloudUrl = "MMCLOUDURL"
SessionCacheSize = 35000
SessionPropPlatform = "platform"
SessionPropOs = "os"
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/team_member.go b/vendor/github.com/mattermost/mattermost-server/v6/model/team_member.go
index cec0a6a6..70fd40c4 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/team_member.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/team_member.go
@@ -69,6 +69,7 @@ type TeamMembersGetOptions struct {
ViewRestrictions *ViewUsersRestrictions
}
+//msgp:ignore TeamInviteReminderData
type TeamInviteReminderData struct {
Interval string
}
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/user.go b/vendor/github.com/mattermost/mattermost-server/v6/model/user.go
index 0b691c6c..5035f9a5 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/user.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/user.go
@@ -703,7 +703,7 @@ func IsValidUserRoles(userRoles string) bool {
return true
}
-// Make sure you acually want to use this function. In context.go there are functions to check permissions
+// Make sure you actually want to use this function. In context.go there are functions to check permissions
// This function should not be used to check permissions.
func (u *User) IsGuest() bool {
return IsInRole(u.Roles, SystemGuestRoleId)
@@ -713,13 +713,13 @@ func (u *User) IsSystemAdmin() bool {
return IsInRole(u.Roles, SystemAdminRoleId)
}
-// Make sure you acually want to use this function. In context.go there are functions to check permissions
+// Make sure you actually want to use this function. In context.go there are functions to check permissions
// This function should not be used to check permissions.
func (u *User) IsInRole(inRole string) bool {
return IsInRole(u.Roles, inRole)
}
-// Make sure you acually want to use this function. In context.go there are functions to check permissions
+// Make sure you actually want to use this function. In context.go there are functions to check permissions
// This function should not be used to check permissions.
func IsInRole(userRoles string, inRole string) bool {
roles := strings.Split(userRoles, " ")
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/utils.go b/vendor/github.com/mattermost/mattermost-server/v6/model/utils.go
index e9170588..c88d9100 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/utils.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/utils.go
@@ -76,7 +76,12 @@ func (sa StringArray) Equals(input StringArray) bool {
// Value converts StringArray to database value
func (sa StringArray) Value() (driver.Value, error) {
- return json.Marshal(sa)
+ j, err := json.Marshal(sa)
+ if err != nil {
+ return nil, err
+ }
+ // non utf8 characters are not supported https://mattermost.atlassian.net/browse/MM-41066
+ return string(j), err
}
// Scan converts database column value to StringArray
@@ -117,6 +122,16 @@ func (m *StringMap) Scan(value interface{}) error {
return errors.New("received value is neither a byte slice nor string")
}
+// Value converts StringMap to database value
+func (m StringMap) Value() (driver.Value, error) {
+ j, err := json.Marshal(m)
+ if err != nil {
+ return nil, err
+ }
+ // non utf8 characters are not supported https://mattermost.atlassian.net/browse/MM-41066
+ return string(j), err
+}
+
func (si *StringInterface) Scan(value interface{}) error {
if value == nil {
return nil
@@ -135,6 +150,16 @@ func (si *StringInterface) Scan(value interface{}) error {
return errors.New("received value is neither a byte slice nor string")
}
+// Value converts StringInterface to database value
+func (si StringInterface) Value() (driver.Value, error) {
+ j, err := json.Marshal(si)
+ if err != nil {
+ return nil, err
+ }
+ // non utf8 characters are not supported https://mattermost.atlassian.net/browse/MM-41066
+ return string(j), err
+}
+
var translateFunc i18n.TranslateFunc
var translateFuncOnce sync.Once
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/version.go b/vendor/github.com/mattermost/mattermost-server/v6/model/version.go
index 6020d5f8..673d4be9 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/version.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/version.go
@@ -13,6 +13,9 @@ import (
// It should be maintained in chronological order with most current
// release at the front of the list.
var versions = []string{
+ "6.4.2",
+ "6.4.1",
+ "6.4.0",
"6.3.0",
"6.2.0",
"6.1.0",
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/shared/filestore/s3_overrides.go b/vendor/github.com/mattermost/mattermost-server/v6/shared/filestore/s3_overrides.go
index e7b29b98..697809ee 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/shared/filestore/s3_overrides.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/shared/filestore/s3_overrides.go
@@ -23,7 +23,7 @@ type customTransport struct {
// RoundTrip implements the http.Roundtripper interface.
func (t *customTransport) RoundTrip(req *http.Request) (*http.Response, error) {
- // Rountrippers should not modify the original request.
+ // Roundtrippers should not modify the original request.
newReq := req.Clone(context.Background())
*newReq.URL = *req.URL
req.URL.Scheme = t.scheme
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/shared/mlog/mlog.go b/vendor/github.com/mattermost/mattermost-server/v6/shared/mlog/mlog.go
index 0f4cc1fe..9b4bb820 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/shared/mlog/mlog.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/shared/mlog/mlog.go
@@ -352,7 +352,7 @@ func (l *Logger) RedirectStdLog(level Level, fields ...Field) func() {
// RemoveTargets safely removes one or more targets based on the filtering method.
// `f` should return true to delete the target, false to keep it.
// When removing a target, best effort is made to write any queued log records before
-// closing, with cxt determining how much time can be spent in total.
+// closing, with ctx determining how much time can be spent in total.
// Note, keep the timeout short since this method blocks certain logging operations.
func (l *Logger) RemoveTargets(ctx context.Context, f func(ti TargetInfo) bool) error {
return l.log.Logr().RemoveTargets(ctx, f)
@@ -379,7 +379,7 @@ func (l *Logger) Flush() error {
return l.log.Logr().FlushWithTimeout(ctx)
}
-// Flush forces all targets to write out any queued log records with the specfified timeout.
+// Flush forces all targets to write out any queued log records with the specified timeout.
func (l *Logger) FlushWithTimeout(ctx context.Context) error {
return l.log.Logr().FlushWithTimeout(ctx)
}
diff --git a/vendor/github.com/mattermost/mattermost-server/v6/model/user_serial_gen.go b/vendor/github.com/mattermost/mattermost-server/v6/model/user_serial_gen.go
index fb40b577..3bcb3cf7 100644
--- a/vendor/github.com/mattermost/mattermost-server/v6/model/user_serial_gen.go
+++ b/vendor/github.com/mattermost/mattermost-server/v6/model/user_serial_gen.go
@@ -17,8 +17,8 @@ func (z *User) DecodeMsg(dc *msgp.Reader) (err error) {
err = msgp.WrapError(err)
return
}
- if zb0001 != 32 {
- err = msgp.ArrayError{Wanted: 32, Got: zb0001}
+ if zb0001 != 33 {
+ err = msgp.ArrayError{Wanted: 33, Got: zb0001}
return
}
z.Id, err = dc.ReadString()
@@ -205,13 +205,18 @@ func (z *User) DecodeMsg(dc *msgp.Reader) (err error) {
err = msgp.WrapError(err, "TermsOfServiceCreateAt")
return
}
+ z.DisableWelcomeEmail, err = dc.ReadBool()
+ if err != nil {
+ err = msgp.WrapError(err, "DisableWelcomeEmail")
+ return
+ }
return
}
// EncodeMsg implements msgp.Encodable
func (z *User) EncodeMsg(en *msgp.Writer) (err error) {
- // array header, size 32
- err = en.Append(0xdc, 0x0, 0x20)
+ // array header, size 33
+ err = en.Append(0xdc, 0x0, 0x21)
if err != nil {
return
}
@@ -389,14 +394,19 @@ func (z *User) EncodeMsg(en *msgp.Writer) (err error) {
err = msgp.WrapError(err, "TermsOfServiceCreateAt")
return
}
+ err = en.WriteBool(z.DisableWelcomeEmail)
+ if err != nil {
+ err = msgp.WrapError(err, "DisableWelcomeEmail")
+ return
+ }
return
}
// MarshalMsg implements msgp.Marshaler
func (z *User) MarshalMsg(b []byte) (o []byte, err error) {
o = msgp.Require(b, z.Msgsize())
- // array header, size 32
- o = append(o, 0xdc, 0x0, 0x20)
+ // array header, size 33
+ o = append(o, 0xdc, 0x0, 0x21)
o = msgp.AppendString(o, z.Id)
o = msgp.AppendInt64(o, z.CreateAt)
o = msgp.AppendInt64(o, z.UpdateAt)
@@ -449,6 +459,7 @@ func (z *User) MarshalMsg(b []byte) (o []byte, err error) {
o = msgp.AppendInt64(o, z.BotLastIconUpdate)
o = msgp.AppendString(o, z.TermsOfServiceId)
o = msgp.AppendInt64(o, z.TermsOfServiceCreateAt)
+ o = msgp.AppendBool(o, z.DisableWelcomeEmail)
return
}
@@ -460,8 +471,8 @@ func (z *User) UnmarshalMsg(bts []byte) (o []byte, err error) {
err = msgp.WrapError(err)
return
}
- if zb0001 != 32 {
- err = msgp.ArrayError{Wanted: 32, Got: zb0001}
+ if zb0001 != 33 {
+ err = msgp.ArrayError{Wanted: 33, Got: zb0001}
return
}
z.Id, bts, err = msgp.ReadStringBytes(bts)
@@ -646,6 +657,11 @@ func (z *User) UnmarshalMsg(bts []byte) (o []byte, err error) {
err = msgp.WrapError(err, "TermsOfServiceCreateAt")
return
}
+ z.DisableWelcomeEmail, bts, err = msgp.ReadBoolBytes(bts)
+ if err != nil {
+ err = msgp.WrapError(err, "DisableWelcomeEmail")
+ return
+ }
o = bts
return
}
@@ -664,7 +680,7 @@ func (z *User) Msgsize() (s int) {
} else {
s += msgp.StringPrefixSize + len(*z.RemoteId)
}
- s += msgp.Int64Size + msgp.BoolSize + msgp.StringPrefixSize + len(z.BotDescription) + msgp.Int64Size + msgp.StringPrefixSize + len(z.TermsOfServiceId) + msgp.Int64Size
+ s += msgp.Int64Size + msgp.BoolSize + msgp.StringPrefixSize + len(z.BotDescription) + msgp.Int64Size + msgp.StringPrefixSize + len(z.TermsOfServiceId) + msgp.Int64Size + msgp.BoolSize
return
}